# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class IpSet(pulumi.CustomResource):
    arn: pulumi.Output[str]
    """
    The ARN of the WAF IPSet.
    """
    ip_set_descriptors: pulumi.Output[list]
    """
    One or more pairs specifying the IP address type (IPV4 or IPV6) and the IP address range (in CIDR format) from which web requests originate.

      * `type` (`str`) - Type of the IP address - `IPV4` or `IPV6`.
      * `value` (`str`) - An IPv4 or IPv6 address specified via CIDR notation.
        e.g. `192.0.2.44/32` or `1111:0000:0000:0000:0000:0000:0000:0000/64`
    """
    name: pulumi.Output[str]
    """
    The name or description of the IPSet.
    """
    def __init__(__self__, resource_name, opts=None, ip_set_descriptors=None, name=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a WAF IPSet Resource

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        ipset = aws.waf.IpSet("ipset", ip_set_descriptors=[
            {
                "type": "IPV4",
                "value": "192.0.7.0/24",
            },
            {
                "type": "IPV4",
                "value": "10.16.16.0/16",
            },
        ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] ip_set_descriptors: One or more pairs specifying the IP address type (IPV4 or IPV6) and the IP address range (in CIDR format) from which web requests originate.
        :param pulumi.Input[str] name: The name or description of the IPSet.

        The **ip_set_descriptors** object supports the following:

          * `type` (`pulumi.Input[str]`) - Type of the IP address - `IPV4` or `IPV6`.
          * `value` (`pulumi.Input[str]`) - An IPv4 or IPv6 address specified via CIDR notation.
            e.g. `192.0.2.44/32` or `1111:0000:0000:0000:0000:0000:0000:0000/64`
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['ip_set_descriptors'] = ip_set_descriptors
            __props__['name'] = name
            __props__['arn'] = None
        super(IpSet, __self__).__init__(
            'aws:waf/ipSet:IpSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, arn=None, ip_set_descriptors=None, name=None):
        """
        Get an existing IpSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The ARN of the WAF IPSet.
        :param pulumi.Input[list] ip_set_descriptors: One or more pairs specifying the IP address type (IPV4 or IPV6) and the IP address range (in CIDR format) from which web requests originate.
        :param pulumi.Input[str] name: The name or description of the IPSet.

        The **ip_set_descriptors** object supports the following:

          * `type` (`pulumi.Input[str]`) - Type of the IP address - `IPV4` or `IPV6`.
          * `value` (`pulumi.Input[str]`) - An IPv4 or IPv6 address specified via CIDR notation.
            e.g. `192.0.2.44/32` or `1111:0000:0000:0000:0000:0000:0000:0000/64`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["arn"] = arn
        __props__["ip_set_descriptors"] = ip_set_descriptors
        __props__["name"] = name
        return IpSet(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop
