# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables


class AnalyticsConfiguration(pulumi.CustomResource):
    bucket: pulumi.Output[str]
    """
    The name of the bucket this analytics configuration is associated with.
    """
    filter: pulumi.Output[dict]
    """
    Object filtering that accepts a prefix, tags, or a logical AND of prefix and tags (documented below).

      * `prefix` (`str`) - Object prefix for filtering.
      * `tags` (`dict`) - Set of object tags for filtering.
    """
    name: pulumi.Output[str]
    """
    Unique identifier of the analytics configuration for the bucket.
    """
    storage_class_analysis: pulumi.Output[dict]
    """
    Configuration for the analytics data export (documented below).

      * `dataExport` (`dict`) - Data export configuration (documented below).
        * `destination` (`dict`) - Specifies the destination for the exported analytics data (documented below).
          * `s3BucketDestination` (`dict`) - Analytics data export currently only supports an S3 bucket destination (documented below).
            * `bucketAccountId` (`str`) - The account ID that owns the destination bucket.
            * `bucketArn` (`str`) - The ARN of the destination bucket.
            * `format` (`str`) - The output format of exported analytics data. Allowed values: `CSV`. Default value: `CSV`.
            * `prefix` (`str`) - Object prefix for filtering.

        * `outputSchemaVersion` (`str`) - The schema version of exported analytics data. Allowed values: `V_1`. Default value: `V_1`.
    """
    def __init__(__self__, resource_name, opts=None, bucket=None, filter=None, name=None, storage_class_analysis=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a S3 bucket [analytics configuration](https://docs.aws.amazon.com/AmazonS3/latest/dev/analytics-storage-class.html) resource.

        ## Example Usage
        ### Add analytics configuration for entire S3 bucket and export results to a second S3 bucket

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.s3.Bucket("example")
        analytics = aws.s3.Bucket("analytics")
        example_entire_bucket = aws.s3.AnalyticsConfiguration("example-entire-bucket",
            bucket=example.bucket,
            storage_class_analysis={
                "data_export": {
                    "destination": {
                        "s3_bucket_destination": {
                            "bucketArn": analytics.arn,
                        },
                    },
                },
            })
        ```
        ### Add analytics configuration with S3 bucket object filter

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.s3.Bucket("example")
        example_filtered = aws.s3.AnalyticsConfiguration("example-filtered",
            bucket=example.bucket,
            filter={
                "prefix": "documents/",
                "tags": {
                    "priority": "high",
                    "class": "blue",
                },
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bucket: The name of the bucket this analytics configuration is associated with.
        :param pulumi.Input[dict] filter: Object filtering that accepts a prefix, tags, or a logical AND of prefix and tags (documented below).
        :param pulumi.Input[str] name: Unique identifier of the analytics configuration for the bucket.
        :param pulumi.Input[dict] storage_class_analysis: Configuration for the analytics data export (documented below).

        The **filter** object supports the following:

          * `prefix` (`pulumi.Input[str]`) - Object prefix for filtering.
          * `tags` (`pulumi.Input[dict]`) - Set of object tags for filtering.

        The **storage_class_analysis** object supports the following:

          * `dataExport` (`pulumi.Input[dict]`) - Data export configuration (documented below).
            * `destination` (`pulumi.Input[dict]`) - Specifies the destination for the exported analytics data (documented below).
              * `s3BucketDestination` (`pulumi.Input[dict]`) - Analytics data export currently only supports an S3 bucket destination (documented below).
                * `bucketAccountId` (`pulumi.Input[str]`) - The account ID that owns the destination bucket.
                * `bucketArn` (`pulumi.Input[str]`) - The ARN of the destination bucket.
                * `format` (`pulumi.Input[str]`) - The output format of exported analytics data. Allowed values: `CSV`. Default value: `CSV`.
                * `prefix` (`pulumi.Input[str]`) - Object prefix for filtering.

            * `outputSchemaVersion` (`pulumi.Input[str]`) - The schema version of exported analytics data. Allowed values: `V_1`. Default value: `V_1`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if bucket is None:
                raise TypeError("Missing required property 'bucket'")
            __props__['bucket'] = bucket
            __props__['filter'] = filter
            __props__['name'] = name
            __props__['storage_class_analysis'] = storage_class_analysis
        super(AnalyticsConfiguration, __self__).__init__(
            'aws:s3/analyticsConfiguration:AnalyticsConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, bucket=None, filter=None, name=None, storage_class_analysis=None):
        """
        Get an existing AnalyticsConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bucket: The name of the bucket this analytics configuration is associated with.
        :param pulumi.Input[dict] filter: Object filtering that accepts a prefix, tags, or a logical AND of prefix and tags (documented below).
        :param pulumi.Input[str] name: Unique identifier of the analytics configuration for the bucket.
        :param pulumi.Input[dict] storage_class_analysis: Configuration for the analytics data export (documented below).

        The **filter** object supports the following:

          * `prefix` (`pulumi.Input[str]`) - Object prefix for filtering.
          * `tags` (`pulumi.Input[dict]`) - Set of object tags for filtering.

        The **storage_class_analysis** object supports the following:

          * `dataExport` (`pulumi.Input[dict]`) - Data export configuration (documented below).
            * `destination` (`pulumi.Input[dict]`) - Specifies the destination for the exported analytics data (documented below).
              * `s3BucketDestination` (`pulumi.Input[dict]`) - Analytics data export currently only supports an S3 bucket destination (documented below).
                * `bucketAccountId` (`pulumi.Input[str]`) - The account ID that owns the destination bucket.
                * `bucketArn` (`pulumi.Input[str]`) - The ARN of the destination bucket.
                * `format` (`pulumi.Input[str]`) - The output format of exported analytics data. Allowed values: `CSV`. Default value: `CSV`.
                * `prefix` (`pulumi.Input[str]`) - Object prefix for filtering.

            * `outputSchemaVersion` (`pulumi.Input[str]`) - The schema version of exported analytics data. Allowed values: `V_1`. Default value: `V_1`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["bucket"] = bucket
        __props__["filter"] = filter
        __props__["name"] = name
        __props__["storage_class_analysis"] = storage_class_analysis
        return AnalyticsConfiguration(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop
